@@ -8,10 +8,11 @@ import (
 	"os"
 	"os/exec"
 	"path/filepath"
+	"strconv"
 	"strings"
 
 	"github.com/charmbracelet/log"
-	"github.com/numtide/treefmt/stats"
+	"github.com/numtide/treefmt/v2/stats"
 	"golang.org/x/sync/errgroup"
 )
 
@@ -50,18 +51,43 @@ func (g *GitReader) Read(ctx context.Context, files []*File) (n int, err error)
 		g.scanner = bufio.NewScanner(r)
 	}
 
+	nextLine := func() (string, error) {
+		line := g.scanner.Text()
+
+		if len(line) == 0 || line[0] != '"' {
+			return line, nil
+		}
+
+		unquoted, err := strconv.Unquote(line)
+		if err != nil {
+			return "", fmt.Errorf("failed to unquote line %s: %w", line, err)
+		}
+
+		return unquoted, nil
+	}
+
 LOOP:
 
 	for n < len(files) {
 		select {
 		// exit early if the context was cancelled
 		case <-ctx.Done():
-			return n, ctx.Err()
+			err = ctx.Err()
+			if err == nil {
+				return n, fmt.Errorf("context cancelled: %w", ctx.Err())
+			}
+
+			return n, nil
 
 		default:
 			// read the next file
 			if g.scanner.Scan() {
-				path := filepath.Join(g.root, g.path, g.scanner.Text())
+				entry, err := nextLine()
+				if err != nil {
+					return n, err
+				}
+
+				path := filepath.Join(g.root, g.path, entry)
 
 				g.log.Debugf("processing file: %s", path)
 
@@ -79,7 +105,7 @@ LOOP:
 
 				files[n] = &File{
 					Path:    path,
-					RelPath: filepath.Join(g.path, g.scanner.Text()),
+					RelPath: filepath.Join(g.path, entry),
 					Info:    info,
 				}
 				n++
@@ -96,7 +122,12 @@ LOOP:
 }
 
 func (g *GitReader) Close() error {
-	return g.eg.Wait()
+	err := g.eg.Wait()
+	if err != nil {
+		return fmt.Errorf("failed to wait for git command to complete: %w", err)
+	}
+
+	return nil
 }
 
 func NewGitReader(
