@@ -8,9 +8,9 @@ import (
 	"testing"
 	"time"
 
-	"github.com/numtide/treefmt/stats"
-	"github.com/numtide/treefmt/test"
-	"github.com/numtide/treefmt/walk"
+	"github.com/numtide/treefmt/v2/stats"
+	"github.com/numtide/treefmt/v2/test"
+	"github.com/numtide/treefmt/v2/walk"
 	"github.com/stretchr/testify/require"
 )
 
@@ -62,8 +62,8 @@ func TestGitReader(t *testing.T) {
 		}
 	}
 
-	as.Equal(32, count)
-	as.Equal(32, statz.Value(stats.Traversed))
+	as.Equal(33, count)
+	as.Equal(33, statz.Value(stats.Traversed))
 	as.Equal(0, statz.Value(stats.Matched))
 	as.Equal(0, statz.Value(stats.Formatted))
 	as.Equal(0, statz.Value(stats.Changed))
